@@ -7,6 +7,7 @@ from os import path, makedirs
 import json
 import csv
 
+
 class JSON2EDCLineageFiles:
     code_version = "0.1.0"
     start_time = datetime.now()
@@ -25,13 +26,23 @@ class JSON2EDCLineageFiles:
         self.schema_directory = "schemas"
         self.json_directory = "jsons"
         self.output_directory = "out/"
-        self.get_settings(configuration_file=configuration_file)
         self.helper = helpers.UtilsHelper()
         self.nr_entity_associations = 0
         self.nr_attribute_associations = 0
+        self.excel_file = None
+        self.resource_items = None
+        self.get_settings(configuration_file=configuration_file)
 
-    def process_files(self):
+    def process_files(self, excelfile=None):
         module = __name__ + "." + currentframe().f_code.co_name
+        if excelfile is not None:
+            self.excel_file = excelfile
+            self.json_directory += excelfile + "/"
+            self.output_directory += excelfile + "/"
+            makedirs(self.output_directory, exist_ok=True)
+
+        print("JSON directory:", self.json_directory)
+        print("Output directory:", self.output_directory)
 
         number_of_files = 0
         overall_result = messages.message["ok"]
@@ -59,17 +70,23 @@ class JSON2EDCLineageFiles:
         return overall_result
 
     def get_settings(self, configuration_file):
+        result = messages.message["ok"]
         try:
             with open(configuration_file) as config:
                 data = json.load(config)
                 self.schema_directory = data["schema_directory"]
                 self.json_directory = data["json_directory"]
                 self.output_directory = data["output_directory"]
+                if self.excel_file is not None:
+                    self.json_directory += self.json_directory + self.excel_file + "/"
+                    self.output_directory += self.output_directory + self.excel_file + "/"
                 self.resource_items = data["resource_items"]
+                # print("resource_items:", self.resource_items)
         except FileNotFoundError or IOError as e:
             result = messages.message["main_config_not_found"]
             result["info"] = "configuration file used: >%s<" % configuration_file
             return result
+        return result
 
     def process_json_data(self, data):
         result = messages.message["ok"]
@@ -180,7 +197,7 @@ class JSON2EDCLineageFiles:
         search_for_files = self.output_directory + "20*--REF_-_data-sources-" + src_or_tgt + "*dataset.json"
         # print("Looking for REF files with search >%s<" % search_for_files)
         list_of_files = glob(search_for_files)
-        if list_of_files is not None:
+        if list_of_files is not None and len(list_of_files) > 0:
             latest_file = max(list_of_files, key=path.getctime)
         else:
             latest_file = None
@@ -207,6 +224,7 @@ class JSON2EDCLineageFiles:
             col_writer.writerow(entry)
 
     def register_result(self, file, result):
+        print("Result for file >%s< is >%s<" % (file, result["code"]))
         filename = self.output_directory + self.start_time_formatted + "-" + __name__ + "-results.txt"
         if path.exists(filename):
             append_or_write = "a"
